"""Heiman Connect - Core library for Heiman Home Assistant integration.

This module provides the core functionality for communicating with Heiman devices
via HTTP API and MQTT protocol.
"""

from .http_client import HeimanHttpClient, HeimanCloudClient
from .mqtt_client import HeimanMqttClient
from .models import (
    HeimanDevice,
    HeimanHome,
    HeimanUser,
    DeviceProperty,
)
from .device_management import (
    DeviceManagement,
    DeviceFilterManager,
    AreaNameSyncManager,
)
from .exceptions import (
    HeimanException,
    HeimanAuthError,
    HeimanConnectionError,
    HeimanApiError,
    HeimanMQTTError,
)

__version__ = "1.0.1"

__all__ = [
    # Version
    "__version__",
    # HTTP Client
    "HeimanHttpClient",
    "HeimanCloudClient",
    # MQTT Client
    "HeimanMqttClient",
    # Models
    "HeimanDevice",
    "HeimanHome",
    "HeimanUser",
    "DeviceProperty",
    # Device Management
    "DeviceManagement",
    "DeviceFilterManager",
    "AreaNameSyncManager",
    # Exceptions
    "HeimanException",
    "HeimanAuthError",
    "HeimanConnectionError",
    "HeimanApiError",
    "HeimanMQTTError",
]
